import React from 'react';
import classnames from 'classnames';
import { useId } from '@highlight-ui/utils-hooks';
import { Typography } from '@highlight-ui/typography';
import { parseMetadata, suffixMetadata, noop } from '@highlight-ui/utils-commons';
/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function () {
  __assign = Object.assign || function __assign(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
      s = arguments[i];

      for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
    }

    return t;
  };

  return __assign.apply(this, arguments);
};

function __rest(s, e) {
  var t = {};

  for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
}

function __spreadArray(to, from, pack) {
  if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
    if (ar || !(i in from)) {
      if (!ar) ar = Array.prototype.slice.call(from, 0, i);
      ar[i] = from[i];
    }
  }
  return to.concat(ar || Array.prototype.slice.call(from));
}

var styles$1 = {
  "checkboxLabelText": "Checkbox-module__1j6zQ7de__v4-3-25",
  "checkboxInput": "Checkbox-module__2xgL7bHv__v4-3-25",
  "checkboxLabel": "Checkbox-module__2qeuuhJu__v4-3-25",
  "checkbox": "Checkbox-module__1kgWLr7T__v4-3-25",
  "checkboxSubLabel": "Checkbox-module__GJgD8tzu__v4-3-25"
};

var CheckboxWithRef = function (_a, ref) {
  var label = _a.label,
      subLabel = _a.subLabel,
      className = _a.className,
      metadata = _a.metadata,
      id = _a.id,
      disabled = _a.disabled,
      onClick = _a.onClick,
      onKeyUp = _a.onKeyUp,
      checkboxProps = __rest(_a, ["label", "subLabel", "className", "metadata", "id", "disabled", "onClick", "onKeyUp"]);

  var generatedId = useId('checkbox-');
  var inputId = id || generatedId;
  return /*#__PURE__*/React.createElement("span", __assign({
    className: classnames(className, styles$1.checkbox)
  }, parseMetadata(metadata)), /*#__PURE__*/React.createElement("input", __assign({
    ref: ref,
    id: inputId,
    type: "checkbox",
    disabled: disabled,
    className: styles$1.checkboxInput,
    onClick: function (e) {
      e.stopPropagation();
      return onClick && onClick(e);
    },
    onKeyUp: function (e) {
      e.stopPropagation();
      return onKeyUp && onKeyUp(e);
    }
  }, checkboxProps, parseMetadata(suffixMetadata(metadata, 'input')))), /*#__PURE__*/React.createElement("label", __assign({
    htmlFor: inputId,
    className: styles$1.checkboxLabel
  }, parseMetadata(suffixMetadata(metadata, 'label'))), label && /*#__PURE__*/React.createElement(Typography, {
    title: label,
    token: "body-base",
    component: "span",
    color: disabled ? 'text-disabled' : 'text-default',
    className: styles$1.checkboxLabelText
  }, label)), label && subLabel && /*#__PURE__*/React.createElement(Typography, __assign({
    title: subLabel,
    token: "caption",
    component: "span",
    color: disabled ? 'text-disabled' : 'text-subdued',
    className: styles$1.checkboxSubLabel
  }, parseMetadata(suffixMetadata(metadata, 'sub-label'))), subLabel));
};

CheckboxWithRef.displayName = 'Checkbox';
var Checkbox = /*#__PURE__*/React.forwardRef(CheckboxWithRef);
var styles = {
  "checkboxGroup": "CheckboxGroup-module__n_4k5Q3g__v4-3-25",
  "checkboxGroupOption": "CheckboxGroup-module__1cRRBG-R__v4-3-25",
  "checkboxGroupHorizontal": "CheckboxGroup-module__2uvnJq3Y__v4-3-25"
};

var valuesToOptions = function (values, options) {
  return options.filter(function (option) {
    return values === null || values === void 0 ? void 0 : values.includes(option.value);
  });
};

var CheckboxGroupWithRef = function (_a, ref) {
  var _b;

  var className = _a.className,
      metadata = _a.metadata,
      name = _a.name,
      _c = _a.disabled,
      disabled = _c === void 0 ? false : _c,
      _d = _a.orientation,
      orientation = _d === void 0 ? 'vertical' : _d,
      options = _a.options,
      _e = _a.value,
      value = _e === void 0 ? [] : _e,
      _f = _a.onChange,
      onChange = _f === void 0 ? noop : _f;
  var generatedName = useId('CheckboxGroupOption-');
  var checkboxGroupName = name || generatedName;
  var selectedOptions = valuesToOptions(value, options);
  return /*#__PURE__*/React.createElement("div", __assign({
    ref: ref,
    className: classnames(className, styles.checkboxGroup, (_b = {}, _b[styles.checkboxGroupHorizontal] = orientation === 'horizontal', _b))
  }, parseMetadata(metadata)), options.map(function (option) {
    return /*#__PURE__*/React.createElement(Checkbox, {
      key: option.value + "-" + checkboxGroupName,
      metadata: option.metadata,
      className: classnames(option.className, styles.checkboxGroupOption),
      id: option.id,
      label: option.label,
      subLabel: option.subLabel,
      value: option.value,
      disabled: disabled || option.disabled,
      checked: value.includes(option.value),
      name: checkboxGroupName,
      onChange: function (e) {
        var isChecked = e.currentTarget.checked;
        var newOptions = isChecked ? __spreadArray(__spreadArray([], selectedOptions, true), [option], false) : selectedOptions.filter(function (v) {
          return v.value !== option.value;
        });
        onChange(newOptions);
      }
    });
  }));
};

CheckboxGroupWithRef.displayName = 'CheckboxGroup';
var CheckboxGroup = /*#__PURE__*/React.forwardRef(CheckboxGroupWithRef);
export { Checkbox, CheckboxGroup };
//# sourceMappingURL=index.js.map
